/*
 *  Copyright 2010 Jesse Long.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */

package net.rumati.sqlblocks;

import net.rumati.sqlblocks.compile.ResultBuilder;

public class MathExpression
    extends Expression
{
    public static enum MathOperator
    {
        ADD("+"),
        SUBTRACT("-"),
        MULTIPLY("*"),
        DIVIDE("/"),
        MODULUS("%");

        private final String sqlToken;

        private MathOperator(String sqlToken)
        {
            this.sqlToken = sqlToken;
        }

        String getSqlToken()
        {
            return sqlToken;
        }
    }

    private final Expression leftHandExpression;
    private final MathOperator operator;
    private final Expression rightHandExpression;

    public MathExpression(Expression leftHandExpression, MathOperator operator,
                          Expression rightHandExpression)
    {
        this.leftHandExpression = leftHandExpression;
        this.operator = operator;
        this.rightHandExpression = rightHandExpression;
    }

    public Expression getLeftHandExpression()
    {
        return leftHandExpression;
    }

    public MathOperator getOperator()
    {
        return operator;
    }

    public Expression getRightHandExpression()
    {
        return rightHandExpression;
    }

    @Override
    final void compile(BaseSQLCompiler compiler, ResultBuilder result)
    {
        compiler.appendMathExpressionSQL(this, result);
    }
}
