/*
 *  Copyright 2010 Jesse Long.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */

package net.rumati.sqlblocks;

import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

/**
 * Represents a list of conditions. This class cannot be directly instantiated. Rather use
 * {@link AndWhereConditionList} and {@link OrWhereConditionList}.
 * @author Jesse Long
 */
public abstract class WhereConditionList
    extends WhereCondition
{
    /**
     * The actual list of conditions.
     */
    private final List<WhereCondition> list = new LinkedList<WhereCondition>();

    /*
     * Package private constructor, because only this package should override
     */
    WhereConditionList(){}

    /**
     * Adds a condition to the list.
     * @param c The {@link WhereCondition} to add to the list.
     * @return This {@link WhereConditionList}
     */
    public WhereConditionList addCondition(WhereCondition c)
    {
        list.add(c);
        return this;
    }

    /**
     * Retrives a unmodifiable list of the conditions in this list.
     * @return The conditions in this list.
     */
    public List<WhereCondition> getConditions()
    {
        return Collections.unmodifiableList(list);
    }

    /**
     * Returns the number of conditions in this list.
     * @return The number of conditions in this list.
     */
    public int numberOfConditions()
    {
        return list.size();
    }
}
