/*
 *  Copyright 2010 Jesse Long.
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *  under the License.
 */

package net.rumati.sqlblocks.compile;

import java.util.List;
import java.util.Map;

public class Result
{
    private final String sql;
    private final Map<String, Integer> parameterNumbers;
    private final String[] parameterNames;

    public Result(String sql,
                  Map<String, Integer> parameterNumbers,
                  List<String> parameterNames)
    {
        this.sql = sql;
        this.parameterNumbers = parameterNumbers;
        this.parameterNames = parameterNames.toArray(new String[parameterNames.size()]);
    }

    public String getSQL()
    {
        return sql;
    }

    public int getParameterNumber(String parameterKey)
    {
        Integer i = parameterNumbers.get(parameterKey);
        if (i == null){
            return -1;
        }
        return i;
    }
    
    public int getNumberOfParameters()
    {
        return parameterNames.length;
    }
    
    public String getParameterName(int parameterIndex)
    {
        if (parameterIndex < 1 || parameterIndex > parameterNames.length){
            throw new ArrayIndexOutOfBoundsException("No such parameter number: " + parameterIndex);
        }
        
        return parameterNames[parameterIndex - 1];
    }
}
